@@ -243,13 +243,14 @@ report <- function(x,
 #' @keywords internal
 createReport <- function(x,
                          reportName,
+                         reportPackage,
                          outfile,
                          ...) {
   ## Check provided outfile
   if (!is.null(outfile)) {
     if (!is.character(outfile) || length(outfile) > 1 ||
         tools::file_ext(outfile) != "pdf") {
-      stop("invalid output filename provided.\n")
+      stop("Invalid output filename provided.\n")
     }
     ## Since latex cannot handle spaces in figure paths knitr converts those
     ## to pathnames with _. To prevent this spaces are not allowed.
@@ -288,7 +289,7 @@ createReport <- function(x,
   ## Construct the output name of the .tex file
   outTex <- file.path(outDir, paste0(outBase, "tex"))
   ## Get the report file from the directory where the package is installed.
-  reportFile <- system.file("reports", reportName, package = "statgenSTA")
+  reportFile <- system.file("reports", reportName, package = reportPackage)
   ## Save knitr options for reset when exiting function.
   knitrOptsOrig <- knitr::opts_chunk$get()
   on.exit(knitr::opts_chunk$set(knitrOptsOrig))
@@ -306,7 +307,7 @@ createReport <- function(x,
                     outBase, "tex")
   cmdRun2 <- paste0(Sys.which("pdflatex"), " -interaction=nonstopmode ",
                     outBase, "tex")
-  ## Run shell commands. System doens't work for windows.
+  ## Run shell commands. System doesn't work for windows.
   ## Two runs needed to get references right.
   switch(tolower(Sys.info()[["sysname"]]),
          windows = {
@@ -331,16 +332,6 @@ createReport <- function(x,
   for (extension in c("aux", "log", "out", "toc", "xwm")) {
     unlink(file.path(outDir, paste0(outBase, extension)))
   }
-  ## A .csv file might be created in the package directory.
-  ## This file is moved to the proper output location.
-  if (file.exists(system.file("reports", paste0(outBase, "csv"),
-                              package = "statgenSTA"))) {
-    file.copy(system.file("reports", paste0(outBase, "csv"),
-                          package = "statgenSTA"),
-              file.path(outDir, paste0(outBase, "csv")), overwrite = TRUE)
-    unlink(system.file("reports", paste0(outBase, "csv"),
-                       package = "statgenSTA"))
-  }
 }
 
 #' Function for escaping special LaTeX characters
